==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QBluetoothPermission_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(permissions)
#include <QtCore/qpermissions.h>
#endif //QT_CONFIG(permissions)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(permissions)


void deleter_QBluetoothPermission(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothPermission")
    QBluetoothPermission *_ptr = reinterpret_cast<QBluetoothPermission *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(permissions)

// emitting (writeConstructors)
// new QBluetoothPermission()
void __qt_construct_QBluetoothPermission_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothPermission()")
#if QT_CONFIG(permissions)
    Q_UNUSED(__java_arguments)
    QBluetoothPermission *__qt_this = new(__qtjambi_ptr) QBluetoothPermission();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// new QBluetoothPermission(QBluetoothPermission)
void __qt_construct_QBluetoothPermission_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothPermission(QBluetoothPermission)")
#if QT_CONFIG(permissions)
    jobject other0 = __java_arguments[0].l;
    const QBluetoothPermission& __qt_other0 = qtjambi_cast<const QBluetoothPermission& >(__jni_env, other0);
    QBluetoothPermission *__qt_this = new(__qtjambi_ptr) QBluetoothPermission(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// destruct QBluetoothPermission
void __qt_destruct_QBluetoothPermission(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothPermission")

#if QT_CONFIG(permissions)

    reinterpret_cast<QBluetoothPermission*>(ptr)->~QBluetoothPermission();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(permissions)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBluetoothPermission::QBluetoothPermission()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_initialize_1native__Lio_qt_core_QBluetoothPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothPermission::QBluetoothPermission()")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothPermission_0, sizeof(QBluetoothPermission), typeid(QBluetoothPermission), false, &deleter_QBluetoothPermission, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothPermission::QBluetoothPermission(QBluetoothPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_initialize_1native__Lio_qt_core_QBluetoothPermission_2Lio_qt_core_QBluetoothPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothPermission::QBluetoothPermission(QBluetoothPermission)")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothPermission_1, sizeof(QBluetoothPermission), typeid(QBluetoothPermission), false, &deleter_QBluetoothPermission, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothPermission::operator=(QBluetoothPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_assign_1native_1cref_1QBluetoothPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::operator=(QBluetoothPermission)", __qt_this)
        const QBluetoothPermission& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothPermission>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothPermission::operator==(QBluetoothPermission,QBluetoothPermission)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_equals_1native_1cref_1QBluetoothPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::operator==(QBluetoothPermission,QBluetoothPermission)", __qt_this)
        const QBluetoothPermission& __qt_arg__2 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothPermission>(arg__2);
        __java_return_value = (*__qt_this) == __qt_arg__2;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(arg__2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothPermission::swap(QBluetoothPermission&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_swap_1native_1ref_1QBluetoothPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::swap(QBluetoothPermission&)", __qt_this)
        QBluetoothPermission& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QBluetoothPermission>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        const QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothPermission(){
    using namespace RegistryAPI;

#if QT_CONFIG(permissions)

    const std::type_info& typeId = registerValueTypeInfo<QBluetoothPermission>("QBluetoothPermission", "io/qt/core/QBluetoothPermission");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothPermission, {
        ConstructorInfo(&__qt_construct_QBluetoothPermission_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothPermission_1, "Lio/qt/core/QBluetoothPermission;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothPermission);
    registerMetaType<QBluetoothPermission>("QBluetoothPermission");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(permissions)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QBluetoothPermission_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(permissions)
#include <QtCore/qpermissions.h>
#endif //QT_CONFIG(permissions)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(permissions)


void deleter_QBluetoothPermission(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothPermission")
    QBluetoothPermission *_ptr = reinterpret_cast<QBluetoothPermission *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(permissions)

// emitting (writeConstructors)
// new QBluetoothPermission()
void __qt_construct_QBluetoothPermission(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothPermission()")
#if QT_CONFIG(permissions)
    Q_UNUSED(__java_arguments)
    QBluetoothPermission *__qt_this = new(__qtjambi_ptr) QBluetoothPermission();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// QBluetoothPermission::QBluetoothPermission()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_initialize_1native__Lio_qt_core_QBluetoothPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothPermission::QBluetoothPermission()")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothPermission, sizeof(QBluetoothPermission), typeid(QBluetoothPermission), false, &deleter_QBluetoothPermission, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBluetoothPermission(QBluetoothPermission)
void __qt_construct_QBluetoothPermission_cref_QBluetoothPermission(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothPermission(QBluetoothPermission)")
#if QT_CONFIG(permissions)
    jobject other0 = __java_arguments[0].l;
    const QBluetoothPermission& __qt_other0 = qtjambi_cast<const QBluetoothPermission& >(__jni_env, other0);
    QBluetoothPermission *__qt_this = new(__qtjambi_ptr) QBluetoothPermission(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// QBluetoothPermission::QBluetoothPermission(QBluetoothPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_initialize_1native__Lio_qt_core_QBluetoothPermission_2Lio_qt_core_QBluetoothPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothPermission::QBluetoothPermission(QBluetoothPermission)")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothPermission_cref_QBluetoothPermission, sizeof(QBluetoothPermission), typeid(QBluetoothPermission), false, &deleter_QBluetoothPermission, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBluetoothPermission
void __qt_destruct_QBluetoothPermission(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothPermission")

#if QT_CONFIG(permissions)

    reinterpret_cast<QBluetoothPermission*>(ptr)->~QBluetoothPermission();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(permissions)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBluetoothPermission::communicationModes()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_communicationModes_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        const QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::communicationModes()const", __qt_this)
        QBluetoothPermission::CommunicationModes __qt_return_value = __qt_this->communicationModes();
        __java_return_value = __qt_return_value;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothPermission::operator=(QBluetoothPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_assign_1native_1cref_1QBluetoothPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::operator=(QBluetoothPermission)", __qt_this)
        const QBluetoothPermission& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothPermission>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothPermission::operator==(QBluetoothPermission,QBluetoothPermission)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_equals_1native_1cref_1QBluetoothPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::operator==(QBluetoothPermission,QBluetoothPermission)", __qt_this)
        const QBluetoothPermission& __qt_arg__2 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothPermission>(arg__2);
        __java_return_value = (*__qt_this) == __qt_arg__2;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(arg__2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothPermission::setCommunicationModes(QBluetoothPermission::CommunicationModes)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_setCommunicationModes_1native_1QBluetoothPermission_1CommunicationModes__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint modes0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::setCommunicationModes(QBluetoothPermission::CommunicationModes)", __qt_this)
        QBluetoothPermission::CommunicationModes __qt_modes0 = qtjambi_cast<QBluetoothPermission::CommunicationModes>(__jni_env, modes0);
        __qt_this->setCommunicationModes(QBluetoothPermission::CommunicationModes(__qt_modes0));
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(modes0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothPermission::swap(QBluetoothPermission&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_swap_1native_1ref_1QBluetoothPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothPermission::swap(QBluetoothPermission&)", __qt_this)
        QBluetoothPermission& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QBluetoothPermission>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBluetoothPermission_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        const QBluetoothPermission *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothPermission(){
    using namespace RegistryAPI;

#if QT_CONFIG(permissions)

    const std::type_info& typeId = registerValueTypeInfo<QBluetoothPermission>("QBluetoothPermission", "io/qt/core/QBluetoothPermission");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothPermission, {
        ConstructorInfo(&__qt_construct_QBluetoothPermission, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothPermission_cref_QBluetoothPermission, "Lio/qt/core/QBluetoothPermission;")
    });
// END: function table

    registerMetaObject(typeId, QBluetoothPermission::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothPermission);
    registerMetaType<QBluetoothPermission>("QBluetoothPermission");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags

#if QT_CONFIG(permissions)
    registerEnumTypeInfo<QBluetoothPermission::CommunicationMode>("QBluetoothPermission::CommunicationMode", "io/qt/core/QBluetoothPermission$CommunicationMode", "QBluetoothPermission::CommunicationModes", "QFlags<QBluetoothPermission::CommunicationMode>", "io/qt/core/QBluetoothPermission$CommunicationModes");
#endif //QT_CONFIG(permissions)
// END: enums and flags

#endif //QT_CONFIG(permissions)

}
